@@ -1,3 +1,23 @@
+/*
+ *  Copyright (C) 2003, 2004 Red Hat, Inc.
+ *
+ *  Nautilus is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 2 of the
+ *  License, or (at your option) any later version.
+ *
+ *  Nautilus is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *  Authors: Alexander Larsson <alexl@redhat.com>
+ *
+ */
 #include <config.h>
 #include <libbonobo.h>
 #include <bonobo/bonobo-main.h>
@@ -9,6 +29,7 @@
 #include "gnome-vfs-private.h"
 #include "gnome-vfs-volume-monitor.h"
 #include "gnome-vfs-volume-monitor-private.h"
+#include "gnome-vfs-volume-monitor-daemon.h"
 
 #define QUIT_TIMEOUT (3*1000)
 
@@ -396,6 +417,19 @@ emit_pre_unmount_volume (PortableServer_Servant _servant,
 	}
 }
 
+static void
+force_probe (PortableServer_Servant _servant,
+	     const GNOME_VFS_Client client,
+	     CORBA_Environment * ev)
+{
+	GnomeVFSVolumeMonitor *monitor;
+	
+	monitor = gnome_vfs_get_volume_monitor ();
+
+	gnome_vfs_volume_monitor_daemon_force_probe (GNOME_VFS_VOLUME_MONITOR_DAEMON (monitor));
+}
+
+
 void
 gnome_vfs_daemon_add_context (const GNOME_VFS_Client client,
 			      GnomeVFSContext *context)
@@ -519,6 +553,7 @@ gnome_vfs_daemon_class_init (GnomeVFSDaemonClass *klass)
 	epv->getVolumes = get_volumes;
 	epv->getDrives = get_drives;
 	epv->emitPreUnmountVolume = emit_pre_unmount_volume;
+	epv->forceProbe = force_probe;
 	
 	gnome_vfs_init ();
 }
