@@ -36,6 +36,8 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-monitor-private.h>
+#include <libgnomevfs/gnome-vfs-private-utils.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
 #include <dirent.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -559,8 +561,16 @@ get_mime_type (GnomeVFSFileInfo *info,
 		 */
 		mime_type = "x-special/symlink";
 	} else {
-		mime_type = gnome_vfs_get_file_mime_type (full_name,
-			stat_buffer, (options & GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE) != 0);
+		if (options & GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE) {
+			mime_type = gnome_vfs_get_file_mime_type (full_name,
+								  stat_buffer, TRUE);
+		} else if (options & GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE) {
+			mime_type = gnome_vfs_get_file_mime_type (full_name,
+								  stat_buffer, FALSE);
+		} else {
+			mime_type = gnome_vfs_get_file_mime_type_fast (full_name,
+								       stat_buffer);
+		}
 	}
 
 	g_assert (mime_type);
@@ -1818,13 +1828,49 @@ rename_helper (const gchar *old_full_name,
 	gboolean old_exists;
 	struct stat statbuf;
 	gint retval;
+	gchar *temp_name;
+	GnomeVFSHandle *temp_handle;
+	GnomeVFSResult result;
 
 	retval = stat (new_full_name, &statbuf);
 	if (retval == 0) {
-		/* If we are not allowed to replace an existing file, return an
-                   error.  */
-		if (! force_replace)
+		/* Special case for files on case insensitive (vfat) filesystems:
+		 * If the old and the new name only differ by case,
+		 * try renaming via a temp file name.
+		 */
+		if (g_ascii_strcasecmp (old_full_name, new_full_name) == 0
+		    && strcmp (old_full_name, new_full_name) != 0 && ! force_replace) {
+
+			if (gnome_vfs_context_check_cancellation (context))
+				return GNOME_VFS_ERROR_CANCELLED;
+			
+			result = gnome_vfs_create_temp (old_full_name, &temp_name, &temp_handle);
+			if (result != GNOME_VFS_OK)
+				return result;
+			gnome_vfs_close (temp_handle);
+			unlink (temp_name);
+			
+			retval = rename (old_full_name, temp_name);
+			if (retval == 0) {
+				if (stat (new_full_name, &statbuf) != 0 
+				    && rename (temp_name, new_full_name) == 0) {
+					/* Success */
+					return GNOME_VFS_OK;
+				}
+				/* Revert the filename back to original */ 
+				retval = rename (temp_name, old_full_name);
+				if (retval == 0) {
+					return GNOME_VFS_ERROR_FILE_EXISTS;
+				}
+			}
+			return gnome_vfs_result_from_errno_code (retval);
+		
+		} else if (! force_replace) {
+			/* If we are not allowed to replace an existing file, 
+			 * return an error.
+			 */
 			return GNOME_VFS_ERROR_FILE_EXISTS;
+		}
 		old_exists = TRUE;
 	} else {
 		old_exists = FALSE;
@@ -2117,7 +2163,7 @@ do_set_file_info (GnomeVFSMethod *method,
 static gboolean
 fam_do_iter_unlocked (void)
 {
-	while (FAMPending(fam_connection)) {
+	while (fam_connection != NULL && FAMPending(fam_connection)) {
 		FAMEvent ev;
 		FileMonitorHandle *handle;
 		gboolean cancelled;
@@ -2126,7 +2172,7 @@ fam_do_iter_unlocked (void)
 		if (FAMNextEvent(fam_connection, &ev) != 1) {
 			FAMClose(fam_connection);
 			g_free(fam_connection);
-			fam_connection = FALSE;
+			fam_connection = NULL;
 			return FALSE;
 		}
 
@@ -2259,22 +2305,26 @@ do_monitor_add (GnomeVFSMethod *method,
 	gnome_vfs_uri_ref (uri);
 	filename = get_path_from_uri (uri);
 
+	G_LOCK (fam_connection);
 	/* We need to queue up incoming messages to avoid blocking on write
 	   if there are many monitors being added */
 	fam_do_iter_unlocked ();
+
+	if (fam_connection == NULL) {
+		G_UNLOCK (fam_connection);
+		return GNOME_VFS_ERROR_NOT_SUPPORTED;
+	}
 	
 	if (monitor_type == GNOME_VFS_MONITOR_FILE) {
-		G_LOCK (fam_connection);
 		FAMMonitorFile (fam_connection, filename, 
 			&handle->request, handle);
-		G_UNLOCK (fam_connection);
 	} else {
-		G_LOCK (fam_connection);
 		FAMMonitorDirectory (fam_connection, filename, 
 			&handle->request, handle);
-		G_UNLOCK (fam_connection);
 	}
 
+	G_UNLOCK (fam_connection);
+	
 	*method_handle_return = (GnomeVFSMethodHandle *)handle;
 
 	g_free (filename);
@@ -2305,6 +2355,11 @@ do_monitor_cancel (GnomeVFSMethod *method,
 	/* We need to queue up incoming messages to avoid blocking on write
 	   if there are many monitors being canceled */
 	fam_do_iter_unlocked ();
+
+	if (fam_connection == NULL) {
+		G_UNLOCK (fam_connection);
+		return GNOME_VFS_ERROR_NOT_SUPPORTED;
+	}
 	
 	FAMCancelMonitor (fam_connection, &handle->request);
 	G_UNLOCK (fam_connection);
