@@ -21,24 +21,19 @@
 
    Author: Ettore Perazzoli <ettore@comm2000.it> */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
-#include <zlib.h>
-#include <time.h>
+#include <glib/galloca.h>
+#include <glib/gmessages.h>
+#include <glib/gstrfuncs.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-module.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
 #include <stdio.h>
 #include <string.h>
+#include <time.h>
+#include <zlib.h>
 
-#include "gnome-vfs-module.h"
-#include "gnome-vfs-mime.h"
-#include "gnome-vfs-ops.h"
-
-
 struct _GZipMethodHandle {
 	GnomeVFSURI *uri;
 	GnomeVFSHandle *parent_handle;
@@ -279,7 +274,7 @@ skip (GnomeVFSHandle *handle,
 	guchar *tmp;
 	GnomeVFSFileSize bytes_read;
 
-	tmp = alloca (num_bytes);
+	tmp = g_alloca (num_bytes);
 
 	result = gnome_vfs_read (handle, tmp, num_bytes, &bytes_read);
 	RETURN_IF_FAIL (result);
@@ -362,12 +357,12 @@ read_gzip_header (GnomeVFSHandle *handle,
 		RETURN_IF_FAIL (skip (handle, 2));
 
 	*modification_time = (buffer[4] | (buffer[5] << 8)
-			      | (buffer[6] << 9) | (buffer[7] << 10));
+			      | (buffer[6] << 16) | (buffer[7] << 24));
 	return GNOME_VFS_OK;
 }
 
 static GnomeVFSResult
-write_gzip_header (GnomeVFSHandle *handle)
+write_gzip_header (GnomeVFSHandle *handle, time_t modification_time)
 {
 	GnomeVFSResult result;
 	guchar buffer[GZIP_HEADER_SIZE];
@@ -377,10 +372,10 @@ write_gzip_header (GnomeVFSHandle *handle)
 	buffer[1] = GZIP_MAGIC_2;     /* magic 2 */
 	buffer[2] = Z_DEFLATED;       /* method */
 	buffer[3] = 0;                /* flags */
-	buffer[4] = 0;                /* time 1 */
-	buffer[5] = 0;                /* time 2 */
-	buffer[6] = 0;                /* time 3 */
-	buffer[7] = 0;                /* time 4 */
+	buffer[4] = (guchar) ((modification_time >>  0) & 0xFF);   /* time 1 */
+	buffer[5] = (guchar) ((modification_time >>  8) & 0xFF);   /* time 2 */
+	buffer[6] = (guchar) ((modification_time >> 16) & 0xFF);   /* time 3 */
+	buffer[7] = (guchar) ((modification_time >> 24) & 0xFF);   /* time 4 */
 	buffer[8] = 0;                /* xflags */
 	buffer[9] = 3;                /* OS (Unix) */
 
@@ -499,12 +494,13 @@ do_open (GnomeVFSMethod *method,
 			return GNOME_VFS_ERROR_INTERNAL;
 		}
 	} else {                          /* GNOME_VFS_OPEN_WRITE */
-		result = write_gzip_header (parent_handle);
+		modification_time = time (NULL);
+		result = write_gzip_header (parent_handle, modification_time);
 		RETURN_IF_FAIL (result);
 
 		/* FIXME bugzilla.eazel.com 1172: need to set modification_time */
 		gzip_handle = gzip_method_handle_new (parent_handle,
-						      (time_t) 0,
+						      modification_time,
 						      uri,
 						      open_mode);
 
@@ -737,7 +733,7 @@ do_get_file_info  (GnomeVFSMethod *method,
 			file_info->name[namelen-3] = '\0';
 
 		/* we can't tell the size without uncompressing it */
-		//file_info->valid_fields &= ~GNOME_VFS_FILE_INFO_FIELDS_SIZE;
+		/*file_info->valid_fields &= ~GNOME_VFS_FILE_INFO_FIELDS_SIZE;*/
 
 		/* guess the mime type of the file inside */
 		/* FIXME bugzilla.eazel.com 2791: guess mime based on contents */
